use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::EOL 0.19

use Test::More 0.88;
use Test::EOL;

my @files = (
    'bin/abc-path-gen',
    'lib/Games/ABC_Path/Generator.pm',
    'lib/Games/ABC_Path/Generator/App.pm',
    'lib/Games/ABC_Path/Generator/Base.pm',
    'lib/Games/ABC_Path/Generator/Coord.pm',
    'lib/Games/ABC_Path/Generator/FinalLayoutObj.pm',
    'lib/Games/ABC_Path/Generator/RiddleObj.pm',
    'lib/Games/ABC_Path/MicrosoftRand.pm',
    't/00-compile.t',
    't/00-load.t',
    't/cmd-line-test.t',
    't/manifest.t',
    't/ms-rand.t',
    't/riddle-obj.t'
);

eol_unix_ok($_, { trailing_whitespace => 1 }) foreach @files;
done_testing;
